cumulusci package
=================

.. automodule:: cumulusci
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   cumulusci.cli
   cumulusci.core
   cumulusci.oauth
   cumulusci.robotframework
   cumulusci.salesforce_api
   cumulusci.tasks
   cumulusci.utils

Submodules
----------

cumulusci.conftest module
-------------------------

.. automodule:: cumulusci.conftest
   :members:
   :undoc-members:
   :show-inheritance:
